@@ -33,7 +33,7 @@ h_fun <- function(incvar, w) {
 #'
 #' @keywords survey
 #' @examples
-#' library(vardpoor)
+#' library(laeken)
 #' data(eusilc) ; names( eusilc ) <- tolower( names( eusilc ) )
 #' library(survey)
 #' des_eusilc <- svydesign(ids = ~rb030, strata =~db040,  weights = ~rb050, data = eusilc)
@@ -96,7 +96,7 @@ densfun <- function(formula, design, x, h = NULL, FUN = "F" , na.rm=FALSE, ...)
 #'
 #' @keywords survey
 #' @examples
-#' library(vardpoor)
+#' library(laeken)
 #' data(eusilc) ; names( eusilc ) <- tolower( names( eusilc ) )
 #' library(survey)
 #' des_eusilc <- svydesign(ids = ~rb030, strata =~db040,  weights = ~rb050, data = eusilc)
@@ -228,7 +228,11 @@ print.cvydstat <- function(x, ...) {
   m <- matrix( x[[1]], nrow = 1 )
   m <- rbind( m , matrix( sqrt( diag(vv) ), nrow = 1 ) )
 
-  dimnames(m) <- list( c( "coef", "SE" ), c( "total", "within", "between" ) )
+  if ( grepl( "watts index decomposition|fgt.* decomposition", attr( x , "statistic" ) ) ) {
+    dimnames(m) <- list( c( "coef", "SE" ), names(coef(x)) )
+  } else {
+    dimnames(m) <- list( c( "coef", "SE" ), c( "total", "within", "between" ) )
+  }
 
   printCoefmat(m, digits = 5)
 
@@ -279,7 +283,7 @@ SE.cvydstat <- function (object, ...) {
 #' @examples
 #'
 #' library(survey)
-#' library(vardpoor)
+#' library(laeken)
 #' data(eusilc) ; names( eusilc ) <- tolower( names( eusilc ) )
 #'
 #' # linearized design: convey_prep must be run as soon as the linearized design has been created
@@ -366,6 +370,23 @@ svyby.convey.design <-
 						)
 
 
+			} else if( 'subgroup' %in% names( list( ... ) ) ){
+
+			  full_design$variables <-
+			    cbind(
+			      getvars(formula, full_design$db$connection, full_design$db$tablename, updates = full_design$updates, subset = full_design$subset),
+			      getvars(by, full_design$db$connection, full_design$db$tablename, updates = full_design$updates, subset = full_design$subset) ,
+			      getvars(list( ... )[["subgroup"]], full_design$db$connection, full_design$db$tablename, updates = full_design$updates, subset = full_design$subset)
+			    )
+
+			  design$variables <-
+			    cbind(
+			      getvars(formula, design$db$connection, design$db$tablename, updates = design$updates, subset = design$subset),
+			      getvars(by, design$db$connection, design$db$tablename, updates = design$updates, subset = design$subset) ,
+			      getvars(list( ... )[["subgroup"]], design$db$connection, design$db$tablename, updates = design$updates, subset = design$subset)
+			    )
+
+
 			} else {
 
 				full_design$variables <-
