@@ -28,7 +28,7 @@
 #'
 #' @examples
 #' library(survey)
-#' library(vardpoor)
+#' library(laeken)
 #' data(eusilc) ; names( eusilc ) <- tolower( names( eusilc ) )
 #'
 #' # linearized design
@@ -77,22 +77,22 @@
 #'
 #'
 #' # database-backed design
-#' library(MonetDBLite)
+#' library(RSQLite)
 #' library(DBI)
-#' dbfolder <- tempdir()
-#' conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+#' dbfile <- tempfile()
+#' conn <- dbConnect( RSQLite::SQLite() , dbfile )
 #' dbWriteTable( conn , 'eusilc' , eusilc )
 #'
 #' dbd_eusilc <-
 #' 	svydesign(
 #' 		ids = ~rb030 ,
-#' 		strata = ~db040 , 
+#' 		strata = ~db040 ,
 #' 		weights = ~rb050 ,
 #' 		data="eusilc",
-#' 		dbname=dbfolder,
-#' 		dbtype="MonetDBLite"
+#' 		dbname=dbfile,
+#' 		dbtype="SQLite"
 #' 	)
-#' 
+#'
 #' dbd_eusilc <- convey_prep( dbd_eusilc )
 #'
 #'
@@ -139,8 +139,6 @@ svyatk <-
 svyatk.survey.design <-
 	function ( formula, design, epsilon = 1, na.rm = FALSE, ... ) {
 
-		if (is.null(attr(design, "full_design"))) stop("you must run the ?convey_prep function on your linearized survey design object immediately after creating it with the svydesign() function.")
-
 		incvar <- model.frame(formula, design$variables, na.action = na.pass)[[1]]
 
 		if (na.rm) {
@@ -231,8 +229,6 @@ svyatk.survey.design <-
 svyatk.svyrep.design <-
 	function(formula, design, epsilon = 1, na.rm=FALSE, ...) {
 
-		if (is.null(attr(design, "full_design"))) stop("you must run the ?convey_prep function on your replicate-weighted survey design object immediately after creating it with the svrepdesign() function.")
-
 		incvar <- model.frame(formula, design$variables, na.action = na.pass)[[1]]
 
 		if(na.rm){
@@ -285,33 +281,7 @@ svyatk.svyrep.design <-
 svyatk.DBIsvydesign <-
 	function (formula, design, ...) {
 
-		if (!( "logical" %in% class(attr(design, "full_design"))) ){
-
-			full_design <- attr( design , "full_design" )
-
-			full_design$variables <-
-				getvars(
-					formula,
-					attr( design , "full_design" )$db$connection,
-					attr( design , "full_design" )$db$tablename,
-					updates = attr( design , "full_design" )$updates,
-					subset = attr( design , "full_design" )$subset
-				)
-
-			attr( design , "full_design" ) <- full_design
-
-			rm( full_design )
-
-		}
-
-		design$variables <-
-			getvars(
-				formula,
-				design$db$connection,
-				design$db$tablename,
-				updates = design$updates,
-				subset = design$subset
-			)
+	  design$variables <- getvars( formula, design$db$connection, design$db$tablename, updates = design$updates, subset = design$subset )
 
 		NextMethod("svyatk", design)
 	}
