@@ -22,7 +22,10 @@
 #'
 #' @seealso \code{\link{svyarpt}}
 #'
-#' @references Guillaume Osier (2009). Variance estimation for complex indicators
+#' @references James Foster, Joel Greer and Erik Thorbecke (1984). A class of decomposable poverty measures.
+#' \emph{Econometrica}, Vol.52, No.3, pp. 761-766.
+#'
+#' Guillaume Osier (2009). Variance estimation for complex indicators
 #' of poverty and inequality. \emph{Journal of the European Survey Research
 #' Association}, Vol.3, No.3, pp. 167-195,
 #' ISSN 1864-3361, URL \url{http://ojs.ub.uni-konstanz.de/srm/article/view/369}.
@@ -35,7 +38,7 @@
 #'
 #' @examples
 #' library(survey)
-#' library(vardpoor)
+#' library(laeken)
 #' data(eusilc) ; names( eusilc ) <- tolower( names( eusilc ) )
 #'
 #' # linearized design
@@ -77,10 +80,10 @@
 #' \dontrun{
 #'
 #' # database-backed design
-#' library(MonetDBLite)
+#' library(RSQLite)
 #' library(DBI)
-#' dbfolder <- tempdir()
-#' conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+#' dbfile <- tempfile()
+#' conn <- dbConnect( RSQLite::SQLite() , dbfile )
 #' dbWriteTable( conn , 'eusilc' , eusilc )
 #'
 #' dbd_eusilc <-
@@ -89,8 +92,8 @@
 #' 		strata = ~db040 ,
 #' 		weights = ~rb050 ,
 #' 		data="eusilc",
-#' 		dbname=dbfolder,
-#' 		dbtype="MonetDBLite"
+#' 		dbname=dbfile,
+#' 		dbtype="SQLite"
 #' 	)
 #'
 #'
@@ -117,26 +120,26 @@
 #'
 #' @export
 svyfgt <-
-	function(formula, design,  ...) {
+  function(formula, design,  ...) {
 
-		if( !( 'g' %in% names(list(...)) ) ) stop( "g= parameter must be specified" )
+    if( !( 'g' %in% names(list(...)) ) ) stop( "g= parameter must be specified" )
 
-		if( !is.na( list(...)[["g"]] ) && !( ( list(...)[["g"]] == 0 ) | ( list(...)[["g"]] >= 1 ) ) ) stop( "g= must be 0 to estimate the headcount ratio or >=1 to estimate the poverty index" )
+    if( !is.na( list(...)[["g"]] ) && !( ( list(...)[["g"]] == 0 ) | ( list(...)[["g"]] >= 1 ) ) ) stop( "g= must be 0 to estimate the headcount ratio or >=1 to estimate the poverty index" )
 
-		if( 'type_thresh' %in% names( list( ... ) ) && !( list(...)[["type_thresh"]] %in% c( 'relq' , 'abs' , 'relm' ) ) ) stop( 'type_thresh= must be "relq" "relm" or "abs".  see ?svyfgt for more detail.' )
+    if( 'type_thresh' %in% names( list( ... ) ) && !( list(...)[["type_thresh"]] %in% c( 'relq' , 'abs' , 'relm' ) ) ) stop( 'type_thresh= must be "relq" "relm" or "abs".  see ?svyfgt for more detail.' )
 
-		if( length( attr( terms.formula( formula ) , "term.labels" ) ) > 1 ) stop( "convey package functions currently only support one variable in the `formula=` argument" )
+    if( length( attr( terms.formula( formula ) , "term.labels" ) ) > 1 ) stop( "convey package functions currently only support one variable in the `formula=` argument" )
 
-		UseMethod("svyfgt", design)
+    UseMethod("svyfgt", design)
 
-	}
+  }
 
 #' @rdname svyfgt
 #' @export
 svyfgt.survey.design <-
   function(formula, design, g, type_thresh="abs",  abs_thresh=NULL, percent = .60, quantiles = .50, na.rm = FALSE, thresh = FALSE, ...){
 
-	if (is.null(attr(design, "full_design"))) stop("you must run the ?convey_prep function on your linearized survey design object immediately after creating it with the svydesign() function.")
+    if (is.null(attr(design, "full_design"))) stop("you must run the ?convey_prep function on your linearized survey design object immediately after creating it with the svydesign() function.")
 
     if( type_thresh == "abs" & is.null( abs_thresh ) ) stop( "abs_thresh= must be specified when type_thresh='abs'" )
 
@@ -162,7 +165,7 @@ svyfgt.survey.design <-
 
     w <- 1/design$prob
 
-	if( is.null( names( design$prob ) ) ) ind <- as.character( seq( length( design$prob ) ) ) else ind <- names(design$prob)
+    if( is.null( names( design$prob ) ) ) ind <- as.character( seq( length( design$prob ) ) ) else ind <- names(design$prob)
 
     N <- sum(w)
 
@@ -180,11 +183,10 @@ svyfgt.survey.design <-
 
     wf <- 1/full_design$prob
 
-	if( is.null( names( full_design$prob ) ) ) ncom <- as.character( seq( length( full_design$prob ) ) ) else ncom <- names(full_design$prob)
+    if( is.null( names( full_design$prob ) ) ) ncom <- as.character( seq( length( full_design$prob ) ) ) else ncom <- names(full_design$prob)
 
-	htot <- h_fun(incvec, wf)
-    if (sum(1/design$prob==0) > 0) ID <- 1*(1/design$prob!=0) else
-    ID <- 1 * ( ncom %in% ind )
+    htot <- h_fun(incvec, wf)
+    if (sum(1/design$prob==0) > 0) ID <- 1*(1/design$prob!=0) else ID <- 1 * ( ncom %in% ind )
 
 
     # linearization
@@ -251,118 +253,116 @@ svyfgt.survey.design <-
 #' @rdname svyfgt
 #' @export
 svyfgt.svyrep.design <-
-	function(formula, design, g, type_thresh="abs", abs_thresh=NULL, percent = .60, quantiles = .50, na.rm = FALSE, thresh = FALSE,...) {
+  function(formula, design, g, type_thresh="abs", abs_thresh=NULL, percent = .60, quantiles = .50, na.rm = FALSE, thresh = FALSE,...) {
 
-		if (is.null(attr(design, "full_design"))) stop("you must run the ?convey_prep function on your replicate-weighted survey design object immediately after creating it with the svrepdesign() function.")
+    if (is.null(attr(design, "full_design"))) stop("you must run the ?convey_prep function on your replicate-weighted survey design object immediately after creating it with the svrepdesign() function.")
 
-		if( type_thresh == "abs" & is.null( abs_thresh ) ) stop( "abs_thresh= must be specified when type_thresh='abs'" )
+    if( type_thresh == "abs" & is.null( abs_thresh ) ) stop( "abs_thresh= must be specified when type_thresh='abs'" )
 
-		# if the class of the full_design attribute is just a TRUE, then the design is
-		# already the full design.  otherwise, pull the full_design from that attribute.
-		if ("logical" %in% class(attr(design, "full_design")))
-		full_design <- design else full_design <- attr(design, "full_design")
+    # if the class of the full_design attribute is just a TRUE, then the design is
+    # already the full design.  otherwise, pull the full_design from that attribute.
+    if ("logical" %in% class(attr(design, "full_design"))) full_design <- design else full_design <- attr(design, "full_design")
 
-		# svyrep design h function
-		h <- function(y,thresh,g) ( ( ( thresh - y ) / thresh )^g ) * ( y <= thresh )
+    # svyrep design h function
+    h <- function(y,thresh,g) ( ( ( thresh - y ) / thresh )^g ) * ( y <= thresh )
 
-		# svyrep design ComputeFGT function
-		ComputeFGT <-
-			function(y, w, thresh, g){
-				N <- sum(w)
-				sum( w * h( y , thresh , g ) ) / N
-			}
+    # svyrep design ComputeFGT function
+    ComputeFGT <-
+      function(y, w, thresh, g){
+        N <- sum(w)
+        sum( w * h( y , thresh , g ) ) / N
+      }
 
 
-		df <- model.frame(design)
-		incvar <- model.frame(formula, design$variables, na.action = na.pass)[[1]]
+    df <- model.frame(design)
+    incvar <- model.frame(formula, design$variables, na.action = na.pass)[[1]]
 
-		if(na.rm){
-			nas<-is.na(incvar)
-			design<-design[!nas,]
-			df <- model.frame(design)
-			incvar <- incvar[!nas]
-		}
+    if(na.rm){
+      nas<-is.na(incvar)
+      design<-design[!nas,]
+      df <- model.frame(design)
+      incvar <- incvar[!nas]
+    }
 
-		ws <- weights(design, "sampling")
+    ws <- weights(design, "sampling")
 
-		df_full<- model.frame(full_design)
-		incvec <- model.frame(formula, full_design$variables, na.action = na.pass)[[1]]
+    df_full<- model.frame(full_design)
+    incvec <- model.frame(formula, full_design$variables, na.action = na.pass)[[1]]
 
-		if(na.rm){
-			nas<-is.na(incvec)
-			full_design<-full_design[!nas,]
-			df_full <- model.frame(full_design)
-			incvec <- incvec[!nas]
-		}
+    if(na.rm){
+      nas<-is.na(incvec)
+      full_design<-full_design[!nas,]
+      df_full <- model.frame(full_design)
+      incvec <- incvec[!nas]
+    }
 
-		wsf <- weights(full_design,"sampling")
-		names(incvec) <- names(wsf) <- row.names(df_full)
-		ind<- row.names(df)
+    wsf <- weights(full_design,"sampling")
+    names(incvec) <- names(wsf) <- row.names(df_full)
+    ind<- row.names(df)
 
-		# poverty threshold
-		if(type_thresh=='relq') th <- percent * computeQuantiles( incvec, wsf, p = quantiles)
-		if(type_thresh=='relm') th <- percent*sum(incvec*wsf)/sum(wsf)
-		if(type_thresh=='abs') th <- abs_thresh
+    # poverty threshold
+    if(type_thresh=='relq') th <- percent * computeQuantiles( incvec, wsf, p = quantiles)
+    if(type_thresh=='relm') th <- percent*sum(incvec*wsf)/sum(wsf)
+    if(type_thresh=='abs') th <- abs_thresh
 
 
-		rval <- ComputeFGT(incvar, ws, g = g, th)
+    rval <- ComputeFGT(incvar, ws, g = g, th)
 
-		wwf <- weights(full_design, "analysis")
+    wwf <- weights(full_design, "analysis")
 
-		qq <-
-			apply(wwf, 2, function(wi){
-				names(wi)<- row.names(df_full)
-				wd<-wi[ind]
-				incd <- incvec[ind]
-				ComputeFGT(incd, wd, g = g, th)}
-			)
-		if(anyNA(qq))variance <- NA
-		else variance <- survey::svrVar(qq, design$scale, design$rscales, mse = design$mse, coef = rval)
+    qq <-
+      apply(wwf, 2, function(wi){
+        names(wi)<- row.names(df_full)
+        wd<-wi[ind]
+        incd <- incvec[ind]
+        ComputeFGT(incd, wd, g = g, th)}
+      )
+    if (anyNA(qq))variance <- NA else variance <- survey::svrVar(qq, design$scale, design$rscales, mse = design$mse, coef = rval)
 
-		variance <- as.matrix( variance )
+    variance <- as.matrix( variance )
 
-		colnames( variance ) <- rownames( variance ) <-  names( rval ) <- strsplit( as.character( formula )[[2]] , ' \\+ ' )[[1]]
-		class(rval) <- c( "cvystat" , "svrepstat" )
-		attr(rval, "var") <- variance
-		attr(rval, "statistic") <- paste0("fgt",g)
-		attr(rval, "lin") <- NA
-		if(thresh) attr(rval, "thresh") <- th
-		rval
-	}
+    colnames( variance ) <- rownames( variance ) <-  names( rval ) <- strsplit( as.character( formula )[[2]] , ' \\+ ' )[[1]]
+    class(rval) <- c( "cvystat" , "svrepstat" )
+    attr(rval, "var") <- variance
+    attr(rval, "statistic") <- paste0("fgt",g)
+    attr(rval, "lin") <- NA
+    if(thresh) attr(rval, "thresh") <- th
+    rval
+  }
 
 #' @rdname svyfgt
 #' @export
 svyfgt.DBIsvydesign <-
-	function (formula, design, ...){
+  function (formula, design, ...){
 
-		if (!( "logical" %in% class(attr(design, "full_design"))) ){
+    if (!( "logical" %in% class(attr(design, "full_design"))) ){
 
-			full_design <- attr( design , "full_design" )
+      full_design <- attr( design , "full_design" )
 
-			full_design$variables <-
-				getvars(
-					formula,
-					attr( design , "full_design" )$db$connection,
-					attr( design , "full_design" )$db$tablename,
-					updates = attr( design , "full_design" )$updates,
-					subset = attr( design , "full_design" )$subset
-				)
+      full_design$variables <-
+        getvars(
+          formula,
+          attr( design , "full_design" )$db$connection,
+          attr( design , "full_design" )$db$tablename,
+          updates = attr( design , "full_design" )$updates,
+          subset = attr( design , "full_design" )$subset
+        )
 
-			attr( design , "full_design" ) <- full_design
+      attr( design , "full_design" ) <- full_design
 
-			rm( full_design )
+      rm( full_design )
 
-		}
+    }
 
-		design$variables <-
-			getvars(
-				formula,
-				design$db$connection,
-				design$db$tablename,
-				updates = design$updates,
-				subset = design$subset
-			)
+    design$variables <-
+      getvars(
+        formula,
+        design$db$connection,
+        design$db$tablename,
+        updates = design$updates,
+        subset = design$subset
+      )
 
-		NextMethod("svyfgt", design)
-	}
+    NextMethod("svyfgt", design)
+  }
 
