@@ -1,5 +1,5 @@
 context("Gini output survey.design and svyrep.design")
-library(vardpoor)
+library(laeken)
 library(survey)
 
 
@@ -55,10 +55,10 @@ test_that("output svygini",{
 
 
 	# database-backed design
-	library(MonetDBLite)
+	library(RSQLite)
 	library(DBI)
-	dbfolder <- tempdir()
-	conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+	dbfile <- tempfile()
+	conn <- dbConnect( RSQLite::SQLite() , dbfile )
 	dbWriteTable( conn , 'eusilc' , eusilc )
 
 	dbd_eusilc <-
@@ -67,8 +67,8 @@ test_that("output svygini",{
 		strata = ~db040 ,
 		weights = ~rb050 ,
 		data="eusilc",
-		dbname=dbfolder,
-		dbtype="MonetDBLite"
+		dbname=dbfile,
+		dbtype="SQLite"
 	  )
 	dbd_eusilc <- convey_prep( dbd_eusilc )
 
@@ -79,6 +79,7 @@ test_that("output svygini",{
 	c2 <- svyby(~ eqincome, by = ~hsize, design = dbd_eusilc, FUN = svygini,deff = FALSE)
 
 	dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
 	test_that("database svygini",{
 	  expect_equal(coef(a1), coef(c1))
@@ -113,10 +114,10 @@ test_that("subsets equal svyby",{
 # second run of database-backed designs #
 
   # database-backed design
-  library(MonetDBLite)
+  library(RSQLite)
   library(DBI)
-  dbfolder <- tempdir()
-  conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+  dbfile <- tempfile()
+  conn <- dbConnect( RSQLite::SQLite() , dbfile )
   dbWriteTable( conn , 'eusilc' , eusilc )
 
   dbd_eusilc <-
@@ -125,8 +126,8 @@ test_that("subsets equal svyby",{
       strata = ~db040 ,
       weights = ~rb050 ,
       data="eusilc",
-      dbname=dbfolder,
-      dbtype="MonetDBLite"
+      dbname=dbfile,
+      dbtype="SQLite"
     )
 
   dbd_eusilc <- convey_prep( dbd_eusilc )
@@ -141,8 +142,8 @@ test_that("subsets equal svyby",{
       rscales = des_eusilc_rep$rscales ,
       type = "bootstrap" ,
       data = "eusilc" ,
-      dbtype = "MonetDBLite" ,
-      dbname = dbfolder ,
+      dbtype="SQLite" ,
+      dbname = dbfile ,
       combined.weights = FALSE
     )
 
@@ -154,6 +155,7 @@ test_that("subsets equal svyby",{
   sby_dbr <- svyby( ~eqincome, by = ~hsize, design = dbd_eusilc_rep, FUN = svygini)
 
   dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
 
   # compare database-backed designs to non-database-backed designs
