@@ -1,5 +1,5 @@
 context("Svyiqalpha output survey.design and svyrep.design")
-library(vardpoor)
+library(laeken)
 library(survey)
 
 
@@ -61,10 +61,10 @@ test_that("output svyiqalpha",{
 
 
 	 # database-backed design
-	library(MonetDBLite)
+	library(RSQLite)
 	library(DBI)
-	dbfolder <- tempdir()
-	conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+	dbfile <- tempfile()
+	conn <- dbConnect( RSQLite::SQLite() , dbfile )
 	dbWriteTable( conn , 'eusilc' , eusilc )
 
 	dbd_eusilc <-
@@ -73,8 +73,8 @@ test_that("output svyiqalpha",{
 			strata = ~db040 ,
 			weights = ~rb050 ,
 			data="eusilc",
-			dbname=dbfolder,
-			dbtype="MonetDBLite"
+			dbname=dbfile,
+			dbtype="SQLite"
 		)
 
 	dbd_eusilc <- convey_prep( dbd_eusilc )
@@ -84,6 +84,7 @@ test_that("output svyiqalpha",{
 	c2 <- svyby(~ eqincome, by = ~hsize, design = dbd_eusilc, FUN = svyiqalpha , alpha = .20 )
 
 	dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
 	test_that("database svyiqalpha",{
 	  expect_equal(coef(a1), coef(c1))
@@ -119,10 +120,10 @@ test_that("subsets equal svyby",{
 # second run of database-backed designs #
 
 	# database-backed design
-	library(MonetDBLite)
+	library(RSQLite)
 	library(DBI)
-	dbfolder <- tempdir()
-	conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+	dbfile <- tempfile()
+	conn <- dbConnect( RSQLite::SQLite() , dbfile )
 	dbWriteTable( conn , 'eusilc' , eusilc )
 
 	dbd_eusilc <-
@@ -131,8 +132,8 @@ test_that("subsets equal svyby",{
 			strata = ~db040 ,
 			weights = ~rb050 ,
 			data="eusilc",
-			dbname=dbfolder,
-			dbtype="MonetDBLite"
+			dbname=dbfile,
+			dbtype="SQLite"
 		)
 
 	dbd_eusilc <- convey_prep( dbd_eusilc )
@@ -147,8 +148,8 @@ test_that("subsets equal svyby",{
 			rscales = des_eusilc_rep$rscales ,
 			type = "bootstrap" ,
 			data = "eusilc" ,
-			dbtype = "MonetDBLite" ,
-			dbname = dbfolder ,
+			dbtype="SQLite" ,
+			dbname = dbfile ,
 			combined.weights = FALSE
 		)
 
@@ -160,6 +161,7 @@ test_that("subsets equal svyby",{
 	sby_dbr <- svyby( ~eqincome, by = ~hsize, design = dbd_eusilc_rep, FUN = svyiqalpha , alpha = .20 )
 
 	dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
 
 	# compare database-backed designs to non-database-backed designs
