@@ -1,5 +1,5 @@
 context("Qsr output survey.design and svyrep.design")
-library(vardpoor)
+library(laeken)
 library(survey)
 
 
@@ -54,10 +54,10 @@ test_that("output svyqsr",{
 
 
 	# database-backed design
-	library(MonetDBLite)
+	library(RSQLite)
 	library(DBI)
-	dbfolder <- tempdir()
-	conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+	dbfile <- tempfile()
+	conn <- dbConnect( RSQLite::SQLite() , dbfile )
 	dbWriteTable( conn , 'eusilc' , eusilc )
 
 	dbd_eusilc <-
@@ -66,8 +66,8 @@ test_that("output svyqsr",{
 		strata = ~db040 ,
 		weights = ~rb050 ,
 		data="eusilc",
-		dbname=dbfolder,
-		dbtype="MonetDBLite"
+		dbname=dbfile,
+		dbtype="SQLite"
 	  )
 	dbd_eusilc <- convey_prep( dbd_eusilc )
 
@@ -76,6 +76,7 @@ test_that("output svyqsr",{
 	c2 <- svyby(~ eqincome, by = ~hsize, design = dbd_eusilc, FUN = svyqsr, quantiles = 0.5, percent = 0.6,deff = FALSE)
 
 	dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
 	test_that("database svyqsr",{
 	  expect_equal(coef(a1), coef(c1))
@@ -110,10 +111,10 @@ test_that("subsets equal svyby",{
 # second run of database-backed designs #
 
   # database-backed design
-  library(MonetDBLite)
+  library(RSQLite)
   library(DBI)
-  dbfolder <- tempdir()
-  conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+  dbfile <- tempfile()
+  conn <- dbConnect( RSQLite::SQLite() , dbfile )
   dbWriteTable( conn , 'eusilc' , eusilc )
 
   dbd_eusilc <-
@@ -122,8 +123,8 @@ test_that("subsets equal svyby",{
       strata = ~db040 ,
       weights = ~rb050 ,
       data="eusilc",
-      dbname=dbfolder,
-      dbtype="MonetDBLite"
+      dbname=dbfile,
+      dbtype="SQLite"
     )
 
   dbd_eusilc <- convey_prep( dbd_eusilc )
@@ -138,8 +139,8 @@ test_that("subsets equal svyby",{
       rscales = des_eusilc_rep$rscales ,
       type = "bootstrap" ,
       data = "eusilc" ,
-      dbtype = "MonetDBLite" ,
-      dbname = dbfolder ,
+      dbtype="SQLite" ,
+      dbname = dbfile ,
       combined.weights = FALSE
     )
 
@@ -151,6 +152,7 @@ test_that("subsets equal svyby",{
   sby_dbr <- svyby( ~eqincome, by = ~hsize, design = dbd_eusilc_rep, FUN = svyqsr)
 
   dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
 
   # compare database-backed designs to non-database-backed designs
