@@ -1,5 +1,5 @@
 context("Rmpg output survey.design and svyrep.design")
-library(vardpoor)
+library(laeken)
 library(survey)
 
 
@@ -53,12 +53,14 @@ test_that("output svyrmpg",{
   expect_equal(sum(confint(b2)[,2]>= coef(b2)),length(coef(b2)))
 })
 
+test_that("database svyrmpg",{
+skip_on_cran()
 
 	# database-backed design
-	library(MonetDBLite)
+	library(RSQLite)
 	library(DBI)
-	dbfolder <- tempdir()
-	conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+	dbfile <- tempfile()
+	conn <- dbConnect( RSQLite::SQLite() , dbfile )
 	dbWriteTable( conn , 'eusilc' , eusilc )
 
 	dbd_eusilc <-
@@ -67,8 +69,8 @@ test_that("output svyrmpg",{
 		strata = ~db040 ,
 		weights = ~rb050 ,
 		data="eusilc",
-		dbname=dbfolder,
-		dbtype="MonetDBLite"
+		dbname=dbfile,
+		dbtype="SQLite"
 	  )
 	dbd_eusilc <- convey_prep( dbd_eusilc )
 
@@ -76,13 +78,12 @@ test_that("output svyrmpg",{
 	c2 <- svyby(~ eqincome, by = ~hsize, design = subset( dbd_eusilc , hsize < 8 ) , FUN = svyrmpg)
 
 	dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
-	test_that("database svyrmpg",{
 	  expect_equal(coef(a1), coef(c1))
 	  expect_equal(coef(a2), coef(c2))
 	  expect_equal(SE(a1), SE(c1))
 	  expect_equal(SE(a2), SE(c2))
-	})
 
 # compare subsetted objects to svyby objects
 sub_des <- svyrmpg( ~eqincome , design = subset( des_eusilc , hsize == 1) )
@@ -90,7 +91,7 @@ sby_des <- svyby( ~eqincome, by = ~hsize, design = subset( des_eusilc , hsize <
 sub_rep <- svyrmpg( ~eqincome , design = subset( des_eusilc_rep , hsize == 1) )
 sby_rep <- svyby( ~eqincome, by = ~hsize, design = subset( des_eusilc_rep , hsize < 8 ) , FUN = svyrmpg)
 
-test_that("subsets equal svyby",{
+# subsets equal svyby
   expect_equal(as.numeric(coef(sub_des)), as.numeric(coef(sby_des))[1])
   expect_equal(as.numeric(coef(sub_rep)), as.numeric(coef(sby_rep))[1])
   expect_equal(as.numeric(SE(sub_des)), as.numeric(SE(sby_des))[1])
@@ -102,7 +103,7 @@ test_that("subsets equal svyby",{
   # coefficients of variation should be within five percent
   cv_dif <- abs(cv(sub_des)-cv(sby_rep)[1])
   expect_lte(cv_dif,5)
-})
+
 
 
 
@@ -110,10 +111,10 @@ test_that("subsets equal svyby",{
 # second run of database-backed designs #
 
   # database-backed design
-  library(MonetDBLite)
+  library(RSQLite)
   library(DBI)
-  dbfolder <- tempdir()
-  conn <- dbConnect( MonetDBLite::MonetDBLite() , dbfolder )
+  dbfile <- tempfile()
+  conn <- dbConnect( RSQLite::SQLite() , dbfile )
   dbWriteTable( conn , 'eusilc' , eusilc )
 
   dbd_eusilc <-
@@ -122,8 +123,8 @@ test_that("subsets equal svyby",{
       strata = ~db040 ,
       weights = ~rb050 ,
       data="eusilc",
-      dbname=dbfolder,
-      dbtype="MonetDBLite"
+      dbname=dbfile,
+      dbtype="SQLite"
     )
 
   dbd_eusilc <- convey_prep( dbd_eusilc )
@@ -138,8 +139,8 @@ test_that("subsets equal svyby",{
       rscales = des_eusilc_rep$rscales ,
       type = "bootstrap" ,
       data = "eusilc" ,
-      dbtype = "MonetDBLite" ,
-      dbname = dbfolder ,
+      dbtype="SQLite" ,
+      dbname = dbfile ,
       combined.weights = FALSE
     )
 
@@ -151,22 +152,25 @@ test_that("subsets equal svyby",{
   sby_dbr <- svyby( ~eqincome, by = ~hsize, design = subset( dbd_eusilc_rep , hsize < 8 ) , FUN = svyrmpg)
 
   dbRemoveTable( conn , 'eusilc' )
+		dbDisconnect( conn )
 
 
   # compare database-backed designs to non-database-backed designs
-  test_that("dbi subsets equal non-dbi subsets",{
+  # dbi subsets equal non-dbi subsets
     expect_equal(coef(sub_des), coef(sub_dbd))
     expect_equal(coef(sub_rep), coef(sub_dbr))
     expect_equal(SE(sub_des), SE(sub_dbd))
     expect_equal(SE(sub_rep), SE(sub_dbr))
-  })
+ 
 
 
   # compare database-backed subsetted objects to database-backed svyby objects
-  test_that("dbi subsets equal dbi svyby",{
+  # dbi subsets equal dbi svyby
     expect_equal(as.numeric(coef(sub_dbd)), as.numeric(coef(sby_dbd))[1])
     expect_equal(as.numeric(coef(sub_dbr)), as.numeric(coef(sby_dbr))[1])
     expect_equal(as.numeric(SE(sub_dbd)), as.numeric(SE(sby_dbd))[1])
     expect_equal(as.numeric(SE(sub_dbr)), as.numeric(SE(sby_dbr))[1])
-  })
+ 
+
+})
 
